==> humhub-1.11.0-beta.2.tar.gz: humhub-1.11.0-beta.2/protected/humhub/modules/space/messages/es/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>¡Este espacio todavía está vacío!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>¡Este espacio está aun vacio!</b><br>Empieza por escribir algo aqui...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>No eres miembro de este espacio y no hay contenido público aún!</b>',
    '<strong>About</strong> the Space' => '<strong>Sobre</strong> este Espacio',
    '<strong>About</strong> your membership' => '<strong>Sobre</strong> tu usuario',
    '<strong>Confirm</strong> image deletion' => '<strong>Confirmar</strong> borrar imagen',
    '<strong>Invite</strong> members' => '<strong>Invitar</strong> miembros',
    '<strong>New</strong> member request' => '<strong>Nuevas</strong> solicitudes de miembros',
    '<strong>New</strong> spaces' => '<strong>Nuevos</strong> espacios',
    '<strong>Request</strong> space membership' => '<strong>Solicitar</strong> suscripción al espacio',
    '<strong>Space</strong> followers' => 'Seguidores del <strong>Espacio</strong>',
    '<strong>Space</strong> members' => 'Miembros del <strong>espacio</strong>',
    '<strong>Space</strong> menu' => 'Menú <strong>espacio</strong>',
    '<strong>Space</strong> tags' => 'Etiquetas de <strong>Espacio</strong>',
    '<strong>Spaces</strong>' => '<strong>Espacios</strong>',
    'About' => 'Acerca de',
    'Accept' => 'Aceptar',
    'Accept Invite' => 'Aceptar invitación',
    'Add users without invitation' => 'Añadir usuarios sin invitación',
    'Admin' => 'Administrador',
    'Administrator:' => 'Administrador:',
    'Administrators' => 'Administradores',
    'Any' => 'Cualquiera',
    'Application message' => 'Mensaje de la aplicación',
    'Archived' => 'Archivado',
    'As owner you cannot revoke your membership!' => '¡Como propietario no puedes revocar tu suscripción!',
    'Blocked users' => 'Usuarios bloqueados',
    'By Name' => 'Por nombre',
    'Cancel' => 'Cancelar',
    'Close' => 'Cerrar',
    'Color' => 'Color',
    'Could not request membership!' => '¡No se puedo solicitar la suscripción!',
    'Created At' => 'Creado hace',
    'Created By' => 'Creado por',
    'Decline' => 'Declinar',
    'Decline Invite' => 'Declinar invitación',
    'Default' => 'Por defecto',
    'Default content visibility' => 'Visibilidad por defecto del contenido',
    'Delete' => 'Borrar',
    'Description' => 'Descripción',
    'Do you really want to delete your profile image?' => '¿Seguro que quieres eliminar tu foto de perfil?',
    'Do you really want to delete your title image?' => '¿Seguro que quieres eliminar tu imagen de cabecera?',
    'Done' => 'Hecho',
    'Email addresses' => 'Direcciones de correo electrónico',
    'Everyone can enter' => 'Todo el mundo puede entrar',
    'Find Spaces by their description or by their tags' => 'Encontrar espacios por su descripción o por su etiquetas',
    'Follow' => 'Seguir',
    'Followers' => 'Seguidores',
    'Following' => 'Siguiendo',
    'Guests' => 'Invitados',
    'Hide Members sidebar in the stream page.' => 'Ocultar la barra lateral de Miembros en la página de actividad.',
    'Homepage' => 'Página de inicio',
    'Homepage (Guests)' => 'Página de inicio (invitados)',
    'Invite' => 'Invitar',
    'Invite and request' => 'Invitar y enviar una solicitud',
    'Invite by email' => 'Invitar por correo electrónico',
    'Invites' => 'Invitaciones',
    'Join' => 'Unirse',
    'Join Policy' => 'Política de acceso',
    'Last Visit' => 'Última visita',
    'Login' => 'Iniciar sesión',
    'Max. 100 characters.' => 'Máx. 100 caracteres.',
    'Member' => 'Miembro',
    'Member since' => 'Miembro desde',
    'Members' => 'Miembros',
    'Moderator' => 'Moderador',
    'Moderator:' => 'Moderador:',
    'Moderators' => 'Moderadores',
    'My Space List' => 'Mi lista de espacios',
    'My space summary' => 'Mi resumen del espacio',
    'Name' => 'Nombre',
    'Neither..nor' => 'Ni..ni',
    'New user by e-mail (comma separated)' => 'Nuevo usuario por correo electrónico (separado por comas)',
    'New user?' => '¿Nuevo usuario?',
    'Newest first' => 'Primero los más recientes',
    'No results found!' => 'Sin resultados encontrados!',
    'No spaces found.' => 'No se encontraron Espacios',
    'Oldest first' => 'Primero los más antiguos',
    'Only by invite' => 'Sólo por invitación',
    'Originator User ID' => 'ID de usuario del originador',
    'Owner' => 'Propietario',
    'Owner:' => 'Propietario:',
    'Pending' => 'Pendiente',
    'Pick users' => 'Selecciona usuarios',
    'Please shortly introduce yourself, to become an approved member of this space.' => 'Por favor, preséntate brevemente, para ser un miembro aprobado de este espacio.',
    'Posts' => 'Entradas',
    'Private' => 'Privado',
    'Private (Invisible)' => 'Privado (Invisible)',
    'Public' => 'Público',
    'Public (Members & Guests)' => 'Público (Miembros y visitantes)',
    'Public (Members only)' => 'Público (sólo miembros)',
    'Public (Registered users only)' => 'Público (sólo usuarios registrados)',
    'Request Message' => 'Mensaje de petición',
    'Role' => 'Rol',
    'Search...' => 'Buscar...',
    'See all' => 'Ver todos',
    'Select all registered users' => 'Seleccionar todos los usuarios registrados',
    'Send' => 'Enviar',
    'Settings' => 'Ajustes',
    'Settings could not be saved!' => 'Los cambios no se han podido guardar!',
    'Show all' => 'Mostrar todos',
    'Shown on About Page.' => 'Mostrar en la página Acerca de',
    'Sorry, you are not allowed to leave this space!' => 'Lo sentimos, no tienes permitido dejar este espacio!',
    'Sorting' => 'Ordenación',
    'Space' => 'Espacio',
    'Space Visibility' => 'Visibilidad de este espacio',
    'Space directory' => 'Directorio de espacios',
    'Space is invisible!' => '¡El espacio es invisible!',
    'Spaces' => 'Espacios',
    'Status' => 'Estado',
    'Stream' => 'Actividad',
    'Tags' => 'Etiquetas',
    'There is no pending invite!' => '¡No hay invitaciones pendientes!',
    'This action is only available for workspace members!' => '¡Esta acción solo está disponible para miembros del espacio!',
    'This user is already a member of this space.' => 'Este usuario ya es miembro de este espacio.',
    'This user is not a member of this space.' => 'Este usuario no es miembro de este espacio.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Para invitar usuarios a este espacio, por favor escribe sus nombres debajo para encontrarlos y escogerlos.',
    'Try other keywords or remove filters.' => 'Intentar otras palabras clave o eliminar filtros.',
    'Updated At' => 'Actualizado hace',
    'Updated By' => 'Actualizado por',
    'Updated by' => 'Actualizado por',
    'User \'{username}\' is already a member of this space!' => 'El usuario \'{username}\' ya es miembro de este espacio!',
    'User invitations have been added to the queue' => 'Las invitaciones a los usuarios se han añadido a la cola',
    'User memberships have been added to the queue' => 'Las solicitudes de participación de usuarios han sido añadidas a la cola',
    'User not found!' => '¡Usuario no encotrado!',
    'Users' => 'Usuarios',
    'Users has been invited.' => 'Se ha invitado al usuario.',
    'Visibility' => 'Visibilidad',
    'Visible for all (members and guests)' => 'Visible para todos (miembros y visitantes)',
    'Would you like to end your membership in Space {spaceName}?' => '¿Quieres dar por terminada tu pertenencia al Espacio {spaceName}?',
    'Would you like to unfollow Space {spaceName}?' => '¿Quieres dejar de seguir el Espacio {spaceName}?',
    'Would you like to unfollow {userName}?' => '¿Quieres dejar de seguir a {userName}?',
    'Would you like to withdraw your request to join Space {spaceName}?' => '¿Quieres retirar tu solicitud de pertenencia al Espacio {spaceName}?',
    'You are not allowed to join this space!' => '¡No puedes unirte a este espacio!',
    'You can also invite external users, which are not registered now. Just add their e-mail addresses separated by comma.' => 'Tambien puedes invitar usuarios externos, que no estén registrados aún. Simplemente añade sus direcciones de correo electrónico separadas por comas.',
    'You cannot create private visible spaces!' => '¡No puedes crear espacios privados visibles!',
    'You cannot create public visible spaces!' => '¡No puedes crear espacios públicos visibles!',
    'You need to login to view contents of this space!' => '¡Necesitas iniciar sesión para ver los contenidos de este espacio!',
    'Your request was successfully submitted to the space administrators.' => 'Tu solicitud ha sido enviada correctamente a los administradores del espacio.',
    '{count} members' => '{count} miembros',
    '{email} is not valid!' => '¡{email} no es válido!',
];

==> humhub-1.16.0-beta.2.tar.gz: humhub-1.16.0-beta.2/protected/humhub/modules/space/messages/es/base.php <==
<?php

return [
    '<b>This space is still empty!</b>' => '<b>¡Este espacio todavía está vacío!</b>',
    '<b>This space is still empty!</b><br>Start by posting something here...' => '<b>¡Este espacio está aun vacio!</b><br>Empieza por escribir algo aqui...',
    '<b>You are not member of this space and there is no public content, yet!</b>' => '<b>No eres miembro de este espacio y no hay contenido público aún!</b>',
    '<strong>About</strong> the Space' => '<strong>Sobre</strong> este Espacio',
    '<strong>About</strong> your membership' => '<strong>Sobre</strong> tu usuario',
    '<strong>Confirm</strong> image deletion' => '<strong>Confirmar</strong> borrar imagen',
    '<strong>Invite</strong> members' => '<strong>Invitar</strong> miembros',
    '<strong>Leave</strong> Space' => '<strong>Abandonar</strong> este espacio',
    '<strong>New</strong> member request' => '<strong>Nuevas</strong> solicitudes de miembros',
    '<strong>New</strong> spaces' => '<strong>Nuevos</strong> espacios',
    '<strong>Request</strong> Membership' => '<strong>Solicitar</strong> suscripción al espacio',
    '<strong>Space</strong> followers' => 'Seguidores del <strong>Espacio</strong>',
    '<strong>Space</strong> members' => 'Miembros del <strong>espacio</strong>',
    '<strong>Space</strong> menu' => 'Menú <strong>espacio</strong>',
    '<strong>Space</strong> tags' => 'Etiquetas de <strong>Espacio</strong>',
    '<strong>Spaces</strong>' => '<strong>Espacios</strong>',
    'About' => 'Acerca de',
    'Accept' => 'Aceptar',
    'Accept Invite' => 'Aceptar invitación',
    'Access to this Space is restricted. Please introduce yourself to become a member.' => 'Por favor, preséntate brevemente, para ser un miembro aprobado de este espacio.',
    'Add users without invitation' => 'Añadir usuarios sin invitación',
    'Admin' => 'Administrador',
    'Administrator:' => 'Administrador:',
    'Administrators' => 'Administradores',
    'Any' => 'Cualquiera',
    'Archived' => 'Archivado',
    'As owner you cannot revoke your membership!' => '¡Como propietario no puedes revocar tu suscripción!',
    'Blocked users' => 'Usuarios bloqueados',
    'By Name' => 'Por nombre',
    'Cancel' => 'Cancelar',
    'Change visibility' => 'Cambiar la visibilidad',
    'Close' => 'Cerrar',
    'Color' => 'Color',
    'Could not request membership!' => '¡No se puedo solicitar la suscripción!',
    'Create new link' => 'Crear nuevo enlace',
    'Created At' => 'Creado hace',
    'Created By' => 'Creado por',
    'Decline' => 'Declinar',
    'Decline Invite' => 'Declinar invitación',
    'Default' => 'Por defecto',
    'Default content visibility' => 'Visibilidad por defecto del contenido',
    'Delete' => 'Borrar',
    'Description' => 'Descripción',
    'Do you really want to delete your profile image?' => '¿Seguro que quieres eliminar tu foto de perfil?',
    'Do you really want to delete your title image?' => '¿Seguro que quieres eliminar tu imagen de cabecera?',
    'Done' => 'Hecho',
    'Email addresses' => 'Direcciones de correo electrónico',
    'Everyone can enter' => 'Todo el mundo puede entrar',
    'Find Spaces by their description or by their tags' => 'Encontrar espacios por su descripción o por su etiquetas',
    'Follow' => 'Seguir',
    'Followers' => 'Seguidores',
    'Following' => 'Siguiendo',
    'Guests' => 'Invitados',
    'Hide About Page' => 'Ocultar la página «Acerca de»',
    'Hide Activity Sidebar Widget' => 'Ocultar el widget «Actividad» de la barra lateral',
    'Hide Followers' => 'Ocultar Seguidores',
    'Hide Members' => 'Ocultar Miembros',
    'Homepage' => 'Página de inicio',
    'Homepage (Non-members)' => 'Página de inicio (no miembros)',
    'I want to become a member because...' => 'Quiero ser miembro porque...',
    'Incorrect name, try again.' => 'Nombre incorrecto. Vuelve a intentarlo.',
    'Invite' => 'Invitar',
    'Invite and request' => 'Invitar y enviar una solicitud',
    'Invite by email' => 'Invitar por correo electrónico',
    'Invite by link' => 'Invitar mediante un enlace',
    'Invite link' => 'Enlace de invitación',
    'Invites' => 'Invitaciones',
    'Join' => 'Unirse',
    'Join Policy' => 'Política de acceso',
    'Last Visit' => 'Última visita',
    'Leave' => 'Abandonar',
    'Login' => 'Iniciar sesión',
    'Max. 100 characters.' => 'Máx. 100 caracteres.',
    'Member' => 'Miembro',
    'Member since' => 'Miembro desde',
    'Members' => 'Miembros',
    'Moderator' => 'Moderador',
    'Moderator:' => 'Moderador:',
    'Moderators' => 'Moderadores',
    'My Space List' => 'Mi lista de espacios',
    'My space summary' => 'Mi resumen del espacio',
    'Name' => 'Nombre',
    'Name / Sort order' => 'Nombre / Orden',
    'Neither..nor' => 'Ni..ni',
    'New user by e-mail (comma separated)' => 'Nuevo usuario por correo electrónico (separado por comas)',
    'New user?' => '¿Nuevo usuario?',
    'Newest first' => 'Primero los más recientes',
    'No results found!' => 'Sin resultados encontrados!',
    'No spaces found.' => 'No se encontraron Espacios',
    'Oldest first' => 'Primero los más antiguos',
    'Only by invite' => 'Sólo por invitación',
    'Originator User ID' => 'ID de usuario del originador',
    'Owner' => 'Propietario',
    'Owner:' => 'Propietario:',
    'Pending' => 'Pendiente',
    'Pick users' => 'Selecciona usuarios',
    'Please note that any links you have previously created will become invalid as soon as you create a new one. Would you like to proceed?' => 'Por favor ten en cuenta que cualquier enlace que hayas creado con anterioridad se convertirá en inválido en el momento en que crees uno nuevo. ¿Quieres seguir adelante?',
    'Posts' => 'Entradas',
    'Private' => 'Privado',
    'Private (Invisible)' => 'Privado (Invisible)',
    'Public' => 'Público',
    'Public (Members & Guests)' => 'Público (Miembros y visitantes)',
    'Public (Members only)' => 'Público (sólo miembros)',
    'Public (Registered users only)' => 'Público (sólo usuarios registrados)',
    'Request Message' => 'Mensaje de petición',
    'Role' => 'Rol',
    'Search...' => 'Buscar...',
    'See all' => 'Ver todos',
    'Select all registered users' => 'Seleccionar todos los usuarios registrados',
    'Send' => 'Enviar',
    'Send the link via email' => 'Enviar el enlace por correo electrónico',
    'Settings' => 'Ajustes',
    'Settings could not be saved!' => 'Los cambios no se han podido guardar!',
    'Show all' => 'Mostrar todos',
    'Show as List' => 'Mostrar como lista',
    'Shown on About Page.' => 'Mostrar en la página Acerca de',
    'Sorry, you are not allowed to leave this space!' => 'Lo sentimos, no tienes permitido dejar este espacio!',
    'Sorting' => 'Ordenación',
    'Space' => 'Espacio',
    'Space Name' => 'Nombre del espacio',
    'Space Visibility' => 'Visibilidad de este espacio',
    'Space directory' => 'Directorio de espacios',
    'Space is invisible!' => '¡El espacio es invisible!',
    'Spaces' => 'Espacios',
    'Status' => 'Estado',
    'Stream' => 'Actividad',
    'Tags' => 'Etiquetas',
    'The default homepage for members of this Space' => 'Página de inicio por defecto para los miembros de este Espacio',
    'The default homepage for non-members and guests visiting this Space' => 'Página de inicio por defecto para no miembros e invitados que visitan este Espacio',
    'The secure link has been copied in your clipboard!' => '¡El enlace seguro se ha copiado al portapapeles!',
    'There is no pending invite!' => '¡No hay invitaciones pendientes!',
    'This action is only available for workspace members!' => '¡Esta acción solo está disponible para miembros del espacio!',
    'This user is already a member of this space.' => 'Este usuario ya es miembro de este espacio.',
    'This user is not a member of this space.' => 'Este usuario no es miembro de este espacio.',
    'To invite users to this space, please type their names below to find and pick them.' => 'Para invitar usuarios a este espacio, por favor escribe sus nombres debajo para encontrarlos y escogerlos.',
    'Try other keywords or remove filters.' => 'Intentar otras palabras clave o eliminar filtros.',
    'Updated At' => 'Actualizado hace',
    'Updated By' => 'Actualizado por',
    'Updated by' => 'Actualizado por',
    'User \'{username}\' is already a member of this space!' => 'El usuario \'{username}\' ya es miembro de este espacio!',
    'User invitations have been added to the queue' => 'Las invitaciones a los usuarios se han añadido a la cola',
    'User memberships have been added to the queue' => 'Las solicitudes de participación de usuarios han sido añadidas a la cola',
    'User not found!' => '¡Usuario no encotrado!',
    'Users' => 'Usuarios',
    'Users has been invited.' => 'Se ha invitado al usuario.',
    'Visibility' => 'Visibilidad',
    'Visible for all (members and guests)' => 'Visible para todos (miembros y visitantes)',
    'Warning: If you change the visibility settings of a Space from public to private, all content within that Space, including posts, comments, attachments etc. will also be set to private. This means that non-members will no longer be able to see, access, or interact with any of the content within that Space.' => 'Atención: Si cambia la configuración de visibilidad del espacio de público a privado, todo el contenido del espacio, incluyendo las publicaciones, los archivos vinculados, etc., serán también considerados privados. Esto significa que los no miembros ya no podrán ver, acceder o interactuar con ningún contenido de este espacio.',
    'Would you like to end your membership in Space {spaceName}?' => '¿Quieres dar por terminada tu pertenencia al Espacio {spaceName}?',
    'Would you like to unfollow Space {spaceName}?' => '¿Quieres dejar de seguir el Espacio {spaceName}?',
    'Would you like to unfollow {userName}?' => '¿Quieres dejar de seguir a {userName}?',
    'Would you like to withdraw your request to join Space {spaceName}?' => '¿Quieres retirar tu solicitud de pertenencia al Espacio {spaceName}?',
    'You are not allowed to join this space!' => '¡No puedes unirte a este espacio!',
    'You can also invite external users by email, which are not registered now. Just add their e-mail addresses separated by comma.' => 'También puedes invitar a usuarios externos que aún no estén registrados mediante correo electrónico. Sólo tienes que añadir sus direcciones de correo electrónico separadas por comas.',
    'You can invite external users who are currently not registered via link. All you need to do is share this secure link with them.' => 'Puedes invitar a usuarios externos que aún no estén registrados mediante un enlace. Lo único que necesitas hacer es compartir con ellos este enlace.',
    'You cannot create private visible spaces!' => '¡No puedes crear espacios privados visibles!',
    'You cannot create public visible spaces!' => '¡No puedes crear espacios públicos visibles!',
    'You need to login to view contents of this space!' => '¡Necesitas iniciar sesión para ver los contenidos de este espacio!',
    'Your Message' => 'Mensaje de la aplicación',
    'Your request was successfully submitted to the space administrators.' => 'Tu solicitud ha sido enviada correctamente a los administradores del espacio.',
    '{count} members' => '{count} miembros',
    '{email} is not valid!' => '¡{email} no es válido!',
    'Advanced Spaces Search' => '',
];
